##############################################################################
# cmake configuration file for LCContent
#
# requires:
#   MacroCheckPackageLibs.cmake for checking package libraries
#
# returns following variables:
#
#   LCContent_FOUND      : set to TRUE if LCContent found
#       if FIND_PACKAGE called with REQUIRED and COMPONENTS arguments
#       LCContent_FOUND is only set to TRUE if ALL components are also found
#       if REQUIRED is NOT set components may or may not be available
#
#   LCContent_ROOT       : path to this LCContent installation
#   LCContent_VERSION    : package version
#   LCContent_LIBRARIES  : list of LCContent libraries (NOT including COMPONENTS)
#   LCContent_INCLUDE_DIRS  : list of paths to be used with INCLUDE_DIRECTORIES
#   LCContent_LIBRARY_DIRS  : list of paths to be used with LINK_DIRECTORIES
#   LCContent_COMPONENT_LIBRARIES      : list of LCContent component libraries
#   LCContent_${COMPONENT}_FOUND       : set to TRUE or FALSE for each library
#   LCContent_${COMPONENT}_LIBRARY     : path to individual libraries
#   LCContent_${COMPONENT}_LIB_DEPENDS : individual library dependencies
#
# @author Jan Engels, Desy
##############################################################################

SET( LCContent_ROOT "$ENV{PANDORA_FQ_DIR}" )
SET( LCContent_VERSION "03.01.05" )


# ---------- include dirs -----------------------------------------------------
# do not store find results in cache
SET( LCContent_INCLUDE_DIRS LCContent_INCLUDE_DIRS-NOTFOUND )
MARK_AS_ADVANCED( LCContent_INCLUDE_DIRS )

FIND_PATH( LCContent_INCLUDE_DIRS
	NAMES LCClustering/ClusteringParentAlgorithm.h
	PATHS ${LCContent_ROOT}/include
	NO_DEFAULT_PATH
)



# ---------- libraries --------------------------------------------------------
INCLUDE( "$ENV{PANDORA_LIB}/cmake/MacroCheckPackageLibs.cmake" )

# only standard libraries should be passed as arguments to CHECK_PACKAGE_LIBS
# additional components are set by cmake in variable PKG_FIND_COMPONENTS
# first argument should be the package name
CHECK_PACKAGE_LIBS( LCContent LCContent )




# ---------- libraries dependencies -------------------------------------------
# this sets LCContent_${COMPONENT}_LIB_DEPENDS variables
INCLUDE( "${LCContent_ROOT}/lib/cmake/LCContentLibDeps.cmake" )
 



# ---------- final checking ---------------------------------------------------
INCLUDE( FindPackageHandleStandardArgs )
# set LCCONTENTNEW_FOUND to TRUE if all listed variables are TRUE and not empty
# LCContent_COMPONENT_VARIABLES will be set if FIND_PACKAGE is called with REQUIRED argument
FIND_PACKAGE_HANDLE_STANDARD_ARGS( LCContent DEFAULT_MSG LCContent_ROOT LCContent_INCLUDE_DIRS LCContent_LIBRARIES ${LCContent_COMPONENT_VARIABLES} )

SET( LCContent_FOUND ${LCCONTENTNEW_FOUND} )

